@@ -2,6 +2,7 @@
 from django.db import models
 from django.db.models.query_utils import Q
 from simple_sso.utils import gen_secret_key
+import datetime
 
 
 def gen_client_key(field):
@@ -42,6 +43,9 @@ class Client(models.Model):
     key = models.CharField(max_length=64, unique=True, default=gen_client_key('key'))
     root_url = models.URLField(verify_exists=False)
     
+    def __unicode__(self):
+        return self.root_url
+    
     def rotate_keys(self):
         self.secret = gen_client_key('secret')()
         self.key = gen_client_key('key')()
@@ -56,5 +60,6 @@ class Token(models.Model):
     request_token = models.CharField(max_length=64, unique=True)
     auth_token = models.CharField(max_length=64, unique=True)
     user = models.ForeignKey('auth.User', null=True)
+    created = models.DateTimeField(default=datetime.datetime.now)
     
     objects = TokenManager()
